pub trait CleanDrop {
// Required method
fn clean_drop(&mut self);
}Expand description
Trait providing an explicit cleanup method that may be invoked prior to Drop.
Required Methods
Sourcefn clean_drop(&mut self)
fn clean_drop(&mut self)
Perform custom cleanup, releasing external resources and breaking strong reference cycles.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".